#!/bin/bash

# define functions to be anything that needs doing across the papers...
function do_prep {
  pageCount=$(pdfinfo Proceedings.pdf | grep '^Pages:' | awk '{ print $2 }')
  echo '<html>'
  echo '<title>GCC07: Proceedings of the 2007 GCC Summit</title>'
  echo '<body>'
  echo '<h2>Proceedings of the 2007 <a href="http://www.gccsummit.org">GCC Summit</a></h2>'
  echo '<br><hr><br>'
  echo '<h2>Draft: DO NOT REDISTRIBUTE UNTIL AFTER THE CONFERENCE</h2>'
  echo '<table width="100%" border="1">'
  echo '<tr><td><b>Proceedings</b> ('${pageCount}' pages)</td><td><a href="Proceedings.dvi">DVI</a> // <a href="Proceedings.pdf">PDF</a> // <a href="Proceedings.ps">PostScript</a></td></tr>'
  echo '<tr><td>Templates</td><td><a href="GCC-Package-2007-V2.tar.gz">GCC-Package-2007-V2.tar.gz</a></td></tr>'
  echo '</table>'
  echo '<br><br>'
  echo "<h2>Individual Papers Received (${recCnt} of ${totCnt})</h2>"
  echo '<table width="100%" border="1">'
  echo '<tr><td><b>Author</b></td><td><b>Title / Link to Draft PDF</b></td></tr>'
  rm -f NotReceived.txt NotReceived.html PDFList.txt
  touch NotReceived.txt 
  touch NotReceived.html
  touch PDFList.txt
}
function do_work {
   if [ $RECEIVED -eq 0 ] ; then
       ## http://www.linuxsymposium.org/2007/view_abstract.php?content_key=86
       if [ $CONTENT_KEY -ne 0 ] ; then
         echo '<tr><td>' "$AUTHOR" '</td><td><a href="http://www.gccsummit.org/2007/view_abstract.php?content_key='${CONTENT_KEY}'">'"$TITLE"'</a></td></tr>' >> NotReceived.html
       else
         echo '<tr><td>' "$AUTHOR" '</td><td>'"$TITLE"'</td></tr>' >> NotReceived.html
       fi
       echo "$AUTHOR" >> NotReceived.txt
      return;
   fi
   dirName=$(echo "$AUTHOR" | awk '{ print $NF }' | tr '[:upper:]' '[:lower:]')
   echo '<tr><td>' "$AUTHOR" '</td><td><a href="'${dirName}'-proc.pdf">'"$TITLE"'</a></td></tr>'
   echo "${dirName}/${dirName}-proc.pdf" >> PDFList.txt
}
function do_wrapup {
  echo '</table>'
  if [ ! -z NotReceived.html ] ; then
      echo '<br><hr><br>'
      echo "<h2>Individual Papers Not Yet Received (${notrecCnt} of ${totCnt})</h2>"
      echo '<table width="100%" border="1">'
      echo '<tr><td><b>AUTHOR</b></td><td><b>Title / Link to Abstract on Conference Site</b></td></tr>'
      cat NotReceived.html
      echo '</table>'
  fi
  echo '<br><hr><br>'
  echo "Page last updated: " $(date) '<br>'
  echo '<br><hr><br>'
  echo '</body>'
  echo '</html>'
  for i in Proceedings.pdf Proceedings.dvi Proceedings.ps ; do
      if [ -r $i ] ; then
	  echo $i >> PDFList.txt
      fi
  done
}

myDataFile=$(dirname $0)/../Data.sh
export notrecCnt=$(grep -c RECEIVED=0 $myDataFile)
export recCnt=$(grep -c RECEIVED=1 $myDataFile)
export totCnt=$(grep -c RECEIVED= $myDataFile)

source $myDataFile


